models.widgets
==============

WidgetManager Class
-------------------

.. autoclass:: pykechain.models.widgets.widgets_manager.WidgetsManager
   :members:

Base Widget Class
-----------------

.. autoclass:: pykechain.models.widgets.Widget
   :members:

Widget Classes
--------------

.. autoclass:: pykechain.models.widgets.widget_models.MetapanelWidget
   :members:

.. autoclass:: pykechain.models.widgets.widget_models.PropertygridWidget
   :members:

.. autoclass:: pykechain.models.widgets.widget_models.UndefinedWidget
   :members:

.. autoclass:: pykechain.models.widgets.widget_models.FilteredgridWidget
   :members:

.. autoclass:: pykechain.models.widgets.widget_models.SupergridWidget
   :members:

.. autoclass:: pykechain.models.widgets.widget_models.AttachmentviewerWidget
   :members:

.. autoclass:: pykechain.models.widgets.widget_models.TasknavigationbarWidget
   :members:

.. autoclass:: pykechain.models.widgets.widget_models.HtmlWidget
   :members:

.. autoclass:: pykechain.models.widgets.widget_models.ServiceWidget
   :members:

.. autoclass:: pykechain.models.widgets.widget_models.NotebookWidget
   :members:

.. autoclass:: pykechain.models.widgets.widget_models.JsonWidget
   :members:

.. autoclass:: pykechain.models.widgets.widget_models.MulticolumnWidget
   :members:

.. autoclass:: pykechain.models.widgets.widget_models.ProgressWidget
   :members:

.. autoclass:: pykechain.models.widgets.widget_models.ScopeWidget
   :members:

.. autoclass:: pykechain.models.widgets.widget_models.SignatureWidget
   :members:

.. autoclass:: pykechain.models.widgets.widget_models.CardWidget
   :members:

.. autoclass:: pykechain.models.widgets.widget_models.ThirdpartyWidget
   :members:

.. autoclass:: pykechain.models.widgets.widget_models.TasksWidget
   :members:
